# Azure Batch Transcription API Python Client

Speech to Text API v3.0.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v3.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage

### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com//.git
```

(you may need to run `pip` with root permission: `sudo pip install git+https://github.com//.git`)

Then import the package:

```python
import azure_transcription_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```

(or `sudo python setup.py install` to install the package for all users)

Then import the package:

```python
import azure_transcription_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import azure_transcription_client
from azure_transcription_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: apiKeyHeader
configuration = azure_transcription_client.Configuration()
configuration.api_key['Ocp-Apim-Subscription-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Ocp-Apim-Subscription-Key'] = 'Bearer'
# Configure API key authorization: apiKeyQuery
configuration = azure_transcription_client.Configuration()
configuration.api_key['subscription-key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['subscription-key'] = 'Bearer'

# create an instance of the API class
api_instance = azure_transcription_client.DefaultApi(azure_transcription_client.ApiClient(configuration))
id = 'id_example' # str | Format - uuid. The identifier of the model that will be copied.
model_copy = azure_transcription_client.ModelCopy() # ModelCopy | The body contains the subscription key of the target subscription. (optional)

try:
    # Copy Model
    api_response = api_instance.copy_model_to_subscription(id, model_copy=model_copy)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DefaultApi->copy_model_to_subscription: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://cognitiveuseprod.cognitiveservices.azure.com/speechtotext/v3.0*

| Class        | Method                                                                                                      | HTTP request                                           | Description                              |
| ------------ | ----------------------------------------------------------------------------------------------------------- | ------------------------------------------------------ | ---------------------------------------- |
| _DefaultApi_ | [**copy_model_to_subscription**](docs/DefaultApi.md#copy_model_to_subscription)                             | **POST** /models/{id}/copyto                           | Copy Model                               |
| _DefaultApi_ | [**create_dataset**](docs/DefaultApi.md#create_dataset)                                                     | **POST** /datasets                                     | Create Dataset                           |
| _DefaultApi_ | [**create_endpoint**](docs/DefaultApi.md#create_endpoint)                                                   | **POST** /endpoints                                    | Create Endpoint                          |
| _DefaultApi_ | [**create_evaluation**](docs/DefaultApi.md#create_evaluation)                                               | **POST** /evaluations                                  | Create Evaluation                        |
| _DefaultApi_ | [**create_hook**](docs/DefaultApi.md#create_hook)                                                           | **POST** /webhooks                                     | Create Web Hook                          |
| _DefaultApi_ | [**create_model**](docs/DefaultApi.md#create_model)                                                         | **POST** /models                                       | Create Model                             |
| _DefaultApi_ | [**create_project**](docs/DefaultApi.md#create_project)                                                     | **POST** /projects                                     | Create Project                           |
| _DefaultApi_ | [**create_transcription**](docs/DefaultApi.md#create_transcription)                                         | **POST** /transcriptions                               | Create Transcription                     |
| _DefaultApi_ | [**delete_base_model_log**](docs/DefaultApi.md#delete_base_model_log)                                       | **DELETE** /endpoints/base/{locale}/files/logs/{logId} | Delete Base Model Endpoint Log           |
| _DefaultApi_ | [**delete_base_model_logs**](docs/DefaultApi.md#delete_base_model_logs)                                     | **DELETE** /endpoints/base/{locale}/files/logs         | Delete All Base Model Endpoint Logs      |
| _DefaultApi_ | [**delete_dataset**](docs/DefaultApi.md#delete_dataset)                                                     | **DELETE** /datasets/{id}                              | Delete Dataset                           |
| _DefaultApi_ | [**delete_endpoint**](docs/DefaultApi.md#delete_endpoint)                                                   | **DELETE** /endpoints/{id}                             | Delete Endpoint                          |
| _DefaultApi_ | [**delete_endpoint_log**](docs/DefaultApi.md#delete_endpoint_log)                                           | **DELETE** /endpoints/{id}/files/logs/{logId}          | Delete Custom Model Endpoint Log         |
| _DefaultApi_ | [**delete_endpoint_logs**](docs/DefaultApi.md#delete_endpoint_logs)                                         | **DELETE** /endpoints/{id}/files/logs                  | Delete All Custom Model Endpoint Logs    |
| _DefaultApi_ | [**delete_evaluation**](docs/DefaultApi.md#delete_evaluation)                                               | **DELETE** /evaluations/{id}                           | Delete Evaluation                        |
| _DefaultApi_ | [**delete_hook**](docs/DefaultApi.md#delete_hook)                                                           | **DELETE** /webhooks/{id}                              | Delete Web Hook                          |
| _DefaultApi_ | [**delete_model**](docs/DefaultApi.md#delete_model)                                                         | **DELETE** /models/{id}                                | Delete Model                             |
| _DefaultApi_ | [**delete_project**](docs/DefaultApi.md#delete_project)                                                     | **DELETE** /projects/{id}                              | Delete Project                           |
| _DefaultApi_ | [**delete_transcription**](docs/DefaultApi.md#delete_transcription)                                         | **DELETE** /transcriptions/{id}                        | Delete Transcription                     |
| _DefaultApi_ | [**get_base_model**](docs/DefaultApi.md#get_base_model)                                                     | **GET** /models/base/{id}                              | Get Base Model                           |
| _DefaultApi_ | [**get_base_model_log**](docs/DefaultApi.md#get_base_model_log)                                             | **GET** /endpoints/base/{locale}/files/logs/{logId}    | Get Base Model Endpoint Log              |
| _DefaultApi_ | [**get_base_model_logs**](docs/DefaultApi.md#get_base_model_logs)                                           | **GET** /endpoints/base/{locale}/files/logs            | Get Base Model Endpoint Logs             |
| _DefaultApi_ | [**get_base_model_manifest**](docs/DefaultApi.md#get_base_model_manifest)                                   | **GET** /models/base/{id}/manifest                     | Get Base Model Manifest                  |
| _DefaultApi_ | [**get_base_models**](docs/DefaultApi.md#get_base_models)                                                   | **GET** /models/base                                   | Get Base Models                          |
| _DefaultApi_ | [**get_dataset**](docs/DefaultApi.md#get_dataset)                                                           | **GET** /datasets/{id}                                 | Get Dataset                              |
| _DefaultApi_ | [**get_dataset_file**](docs/DefaultApi.md#get_dataset_file)                                                 | **GET** /datasets/{id}/files/{fileId}                  | Get Dataset File                         |
| _DefaultApi_ | [**get_dataset_files**](docs/DefaultApi.md#get_dataset_files)                                               | **GET** /datasets/{id}/files                           | Get Dataset Files                        |
| _DefaultApi_ | [**get_datasets**](docs/DefaultApi.md#get_datasets)                                                         | **GET** /datasets                                      | Get Datasets                             |
| _DefaultApi_ | [**get_datasets_for_project**](docs/DefaultApi.md#get_datasets_for_project)                                 | **GET** /projects/{id}/datasets                        | Get Datasets for Project                 |
| _DefaultApi_ | [**get_endpoint**](docs/DefaultApi.md#get_endpoint)                                                         | **GET** /endpoints/{id}                                | Get Endpoint                             |
| _DefaultApi_ | [**get_endpoint_log**](docs/DefaultApi.md#get_endpoint_log)                                                 | **GET** /endpoints/{id}/files/logs/{logId}             | Get Custom Model Endpoint Log            |
| _DefaultApi_ | [**get_endpoint_logs**](docs/DefaultApi.md#get_endpoint_logs)                                               | **GET** /endpoints/{id}/files/logs                     | Get Custom Model Endpoint Logs           |
| _DefaultApi_ | [**get_endpoints**](docs/DefaultApi.md#get_endpoints)                                                       | **GET** /endpoints                                     | Get Endpoints                            |
| _DefaultApi_ | [**get_endpoints_for_project**](docs/DefaultApi.md#get_endpoints_for_project)                               | **GET** /projects/{id}/endpoints                       | Get Endpoints for Project                |
| _DefaultApi_ | [**get_evaluation**](docs/DefaultApi.md#get_evaluation)                                                     | **GET** /evaluations/{id}                              | Get Evaluation                           |
| _DefaultApi_ | [**get_evaluation_file**](docs/DefaultApi.md#get_evaluation_file)                                           | **GET** /evaluations/{id}/files/{fileId}               | Get Evaluation File                      |
| _DefaultApi_ | [**get_evaluation_files**](docs/DefaultApi.md#get_evaluation_files)                                         | **GET** /evaluations/{id}/files                        | Get Evaluation Files                     |
| _DefaultApi_ | [**get_evaluations**](docs/DefaultApi.md#get_evaluations)                                                   | **GET** /evaluations                                   | Get Evaluations                          |
| _DefaultApi_ | [**get_evaluations_for_project**](docs/DefaultApi.md#get_evaluations_for_project)                           | **GET** /projects/{id}/evaluations                     | Get Evaluations for Project              |
| _DefaultApi_ | [**get_health_status**](docs/DefaultApi.md#get_health_status)                                               | **GET** /healthstatus                                  | Get Health Status                        |
| _DefaultApi_ | [**get_hook**](docs/DefaultApi.md#get_hook)                                                                 | **GET** /webhooks/{id}                                 | Get Web Hook                             |
| _DefaultApi_ | [**get_hooks**](docs/DefaultApi.md#get_hooks)                                                               | **GET** /webhooks                                      | Get Web Hooks                            |
| _DefaultApi_ | [**get_model**](docs/DefaultApi.md#get_model)                                                               | **GET** /models/{id}                                   | Get Model                                |
| _DefaultApi_ | [**get_model_manifest**](docs/DefaultApi.md#get_model_manifest)                                             | **GET** /models/{id}/manifest                          | Get Custom Model Manifest                |
| _DefaultApi_ | [**get_models**](docs/DefaultApi.md#get_models)                                                             | **GET** /models                                        | Get Custom Models                        |
| _DefaultApi_ | [**get_models_for_project**](docs/DefaultApi.md#get_models_for_project)                                     | **GET** /projects/{id}/models                          | Get Models for Project                   |
| _DefaultApi_ | [**get_project**](docs/DefaultApi.md#get_project)                                                           | **GET** /projects/{id}                                 | Get Project                              |
| _DefaultApi_ | [**get_projects**](docs/DefaultApi.md#get_projects)                                                         | **GET** /projects                                      | Get Projects                             |
| _DefaultApi_ | [**get_supported_locales_for_datasets**](docs/DefaultApi.md#get_supported_locales_for_datasets)             | **GET** /datasets/locales                              | Get Supported Locales for Datasets       |
| _DefaultApi_ | [**get_supported_locales_for_endpoints**](docs/DefaultApi.md#get_supported_locales_for_endpoints)           | **GET** /endpoints/locales                             | Get Supported Locales for Endpoints      |
| _DefaultApi_ | [**get_supported_locales_for_evaluations**](docs/DefaultApi.md#get_supported_locales_for_evaluations)       | **GET** /evaluations/locales                           | Get Supported Locales for Evaluations    |
| _DefaultApi_ | [**get_supported_locales_for_models**](docs/DefaultApi.md#get_supported_locales_for_models)                 | **GET** /models/locales                                | Get Supported Locales for Models         |
| _DefaultApi_ | [**get_supported_locales_for_transcriptions**](docs/DefaultApi.md#get_supported_locales_for_transcriptions) | **GET** /transcriptions/locales                        | Get Supported Locales for Transcriptions |
| _DefaultApi_ | [**get_supported_project_locales**](docs/DefaultApi.md#get_supported_project_locales)                       | **GET** /projects/locales                              | Get Supported Locales for Projects       |
| _DefaultApi_ | [**get_transcription**](docs/DefaultApi.md#get_transcription)                                               | **GET** /transcriptions/{id}                           | Get Transcription                        |
| _DefaultApi_ | [**get_transcription_file**](docs/DefaultApi.md#get_transcription_file)                                     | **GET** /transcriptions/{id}/files/{fileId}            | Get Transcription File                   |
| _DefaultApi_ | [**get_transcription_files**](docs/DefaultApi.md#get_transcription_files)                                   | **GET** /transcriptions/{id}/files                     | Get Transcription Files                  |
| _DefaultApi_ | [**get_transcriptions**](docs/DefaultApi.md#get_transcriptions)                                             | **GET** /transcriptions                                | Get Transcriptions                       |
| _DefaultApi_ | [**get_transcriptions_for_project**](docs/DefaultApi.md#get_transcriptions_for_project)                     | **GET** /projects/{id}/transcriptions                  | Get Transcriptions for Project           |
| _DefaultApi_ | [**ping_hook**](docs/DefaultApi.md#ping_hook)                                                               | **POST** /webhooks/{id}/ping                           | Ping Web Hook                            |
| _DefaultApi_ | [**test_hook**](docs/DefaultApi.md#test_hook)                                                               | **POST** /webhooks/{id}/test                           | Test Web Hook                            |
| _DefaultApi_ | [**update_dataset**](docs/DefaultApi.md#update_dataset)                                                     | **PATCH** /datasets/{id}                               | Update Dataset                           |
| _DefaultApi_ | [**update_endpoint**](docs/DefaultApi.md#update_endpoint)                                                   | **PATCH** /endpoints/{id}                              | Update Endpoint                          |
| _DefaultApi_ | [**update_evaluation**](docs/DefaultApi.md#update_evaluation)                                               | **PATCH** /evaluations/{id}                            | Update Evaluation                        |
| _DefaultApi_ | [**update_hook**](docs/DefaultApi.md#update_hook)                                                           | **PATCH** /webhooks/{id}                               | Update Web Hook                          |
| _DefaultApi_ | [**update_model**](docs/DefaultApi.md#update_model)                                                         | **PATCH** /models/{id}                                 | Update Model                             |
| _DefaultApi_ | [**update_project**](docs/DefaultApi.md#update_project)                                                     | **PATCH** /projects/{id}                               | Update Project                           |
| _DefaultApi_ | [**update_transcription**](docs/DefaultApi.md#update_transcription)                                         | **PATCH** /transcriptions/{id}                         | Update Transcription                     |
| _DefaultApi_ | [**upload_dataset_from_form**](docs/DefaultApi.md#upload_dataset_from_form)                                 | **POST** /datasets/upload                              | Create Dataset from Form                 |

## Documentation For Models

- [ApiSpeechtotextV30DatasetsLocalesGet200ApplicationJsonResponse](docs/ApiSpeechtotextV30DatasetsLocalesGet200ApplicationJsonResponse.md)
- [ApiSpeechtotextV30EndpointsLocalesGet200ApplicationJsonResponse](docs/ApiSpeechtotextV30EndpointsLocalesGet200ApplicationJsonResponse.md)
- [ApiSpeechtotextV30EvaluationsLocalesGet200ApplicationJsonResponse](docs/ApiSpeechtotextV30EvaluationsLocalesGet200ApplicationJsonResponse.md)
- [ApiSpeechtotextV30ModelsLocalesGet200ApplicationJsonResponse](docs/ApiSpeechtotextV30ModelsLocalesGet200ApplicationJsonResponse.md)
- [ApiSpeechtotextV30ProjectsLocalesGet200ApplicationJsonResponse](docs/ApiSpeechtotextV30ProjectsLocalesGet200ApplicationJsonResponse.md)
- [ApiSpeechtotextV30TranscriptionsLocalesGet200ApplicationJsonResponse](docs/ApiSpeechtotextV30TranscriptionsLocalesGet200ApplicationJsonResponse.md)
- [Component](docs/Component.md)
- [Dataset](docs/Dataset.md)
- [DatasetProperties](docs/DatasetProperties.md)
- [DatasetUpdate](docs/DatasetUpdate.md)
- [Endpoint](docs/Endpoint.md)
- [EndpointLinks](docs/EndpointLinks.md)
- [EndpointProperties](docs/EndpointProperties.md)
- [EndpointPropertiesUpdate](docs/EndpointPropertiesUpdate.md)
- [EndpointUpdate](docs/EndpointUpdate.md)
- [EntityError](docs/EntityError.md)
- [EntityReference](docs/EntityReference.md)
- [Error](docs/Error.md)
- [ErrorContent](docs/ErrorContent.md)
- [ErrorDetail](docs/ErrorDetail.md)
- [Evaluation](docs/Evaluation.md)
- [EvaluationProperties](docs/EvaluationProperties.md)
- [EvaluationUpdate](docs/EvaluationUpdate.md)
- [File](docs/File.md)
- [FileLinks](docs/FileLinks.md)
- [FileProperties](docs/FileProperties.md)
- [HealthStatus](docs/HealthStatus.md)
- [InnerError](docs/InnerError.md)
- [InnerErrorV2](docs/InnerErrorV2.md)
- [InternalModel](docs/InternalModel.md)
- [Links](docs/Links.md)
- [ManagementModel](docs/ManagementModel.md)
- [ManagementModelArray](docs/ManagementModelArray.md)
- [ManagementModelProperties](docs/ManagementModelProperties.md)
- [Model](docs/Model.md)
- [ModelCopy](docs/ModelCopy.md)
- [ModelDeprecationDates](docs/ModelDeprecationDates.md)
- [ModelFile](docs/ModelFile.md)
- [ModelLinks](docs/ModelLinks.md)
- [ModelManifest](docs/ModelManifest.md)
- [ModelProperties](docs/ModelProperties.md)
- [ModelUpdate](docs/ModelUpdate.md)
- [PaginatedDatasets](docs/PaginatedDatasets.md)
- [PaginatedEndpoints](docs/PaginatedEndpoints.md)
- [PaginatedEvaluations](docs/PaginatedEvaluations.md)
- [PaginatedFiles](docs/PaginatedFiles.md)
- [PaginatedModels](docs/PaginatedModels.md)
- [PaginatedProjects](docs/PaginatedProjects.md)
- [PaginatedTranscriptions](docs/PaginatedTranscriptions.md)
- [PaginatedWebHooks](docs/PaginatedWebHooks.md)
- [Project](docs/Project.md)
- [ProjectLinks](docs/ProjectLinks.md)
- [ProjectProperties](docs/ProjectProperties.md)
- [ProjectUpdate](docs/ProjectUpdate.md)
- [Transcription](docs/Transcription.md)
- [TranscriptionProperties](docs/TranscriptionProperties.md)
- [TranscriptionUpdate](docs/TranscriptionUpdate.md)
- [WebHook](docs/WebHook.md)
- [WebHookEvents](docs/WebHookEvents.md)
- [WebHookEvents1](docs/WebHookEvents1.md)
- [WebHookLinks](docs/WebHookLinks.md)
- [WebHookProperties](docs/WebHookProperties.md)
- [WebHookPropertiesUpdate](docs/WebHookPropertiesUpdate.md)
- [WebHookUpdate](docs/WebHookUpdate.md)

## Documentation For Authorization

## apiKeyHeader

- **Type**: API key
- **API key parameter name**: Ocp-Apim-Subscription-Key
- **Location**: HTTP header

## apiKeyQuery

- **Type**: API key
- **API key parameter name**: subscription-key
- **Location**: URL query string

## Author
